@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # isbnlib - tools for extracting, cleaning and transforming ISBNs
-# Copyright (C) 2014  Alexandre Lima Conde
+# Copyright (C) 2014-2018 Alexandre Lima Conde
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,8 +15,6 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-
 """isbnlib main file.
 
 Tools for extracting, cleaning, transforming and validating ISBN ids.
@@ -27,7 +25,6 @@ import re
 
 LOGGER = logging.getLogger(__name__)
 
-
 RE_ISBN10 = re.compile(r'ISBN\x20(?=.{13}$)\d{1,5}([- ])\d{1,7}'
                        r'\1\d{1,6}\1(\d|X)$|[- 0-9X]{10,16}')
 RE_ISBN13 = re.compile(r'97[89]{1}(?:-?\d){10,16}|97[89]{1}[- 0-9]{10,16}')
@@ -39,25 +36,24 @@ RE_STRICT = re.compile(r'^(?:ISBN(?:-1[03])?:? )?(?=[0-9X]{10}$|'
                        r'[- ]?[0-9]+[- ]?[0-9]+[- ]?[0-9X]$',
                        re.I | re.M | re.S)
 RE_NORMAL = re.compile(r'97[89]{1}(?:-?\d){10}|\d{9}[0-9X]{1}|'
-                       r'[-0-9X]{10,16}',
-                       re.I | re.M | re.S)
+                       r'[-0-9X]{10,16}', re.I | re.M | re.S)
 RE_LOOSE = re.compile(r'[- 0-9X]{10,19}', re.I | re.M | re.S)
 ISBN13_PREFIX = '978'
 LEGAL = '0123456789xXisbnISBN- '
 
 
-def _check_digit10(firstninedigits):
+def check_digit10(firstninedigits):
     """Check sum ISBN-10."""
     # minimum checks
     if len(firstninedigits) != 9:
         return None
     try:
         int(firstninedigits)
-    except:  # pragma: no cover
+    except Exception:  # pragma: no cover
         return None
     # checksum
-    val = sum((i + 2) * int(x) for
-              i, x in enumerate(reversed(firstninedigits)))
+    val = sum(
+        (i + 2) * int(x) for i, x in enumerate(reversed(firstninedigits)))
     remainder = int(val % 11)
     if remainder == 0:
         tenthdigit = 0
@@ -68,18 +64,18 @@ def _check_digit10(firstninedigits):
     return str(tenthdigit)
 
 
-def _check_digit13(firsttwelvedigits):
+def check_digit13(firsttwelvedigits):
     """Check sum ISBN-13."""
     # minimum checks
     if len(firsttwelvedigits) != 12:
         return None
     try:
         int(firsttwelvedigits)
-    except:  # pragma: no cover
+    except Exception:  # pragma: no cover
         return None
     # checksum
-    val = sum((i % 2 * 2 + 1) * int(x) for
-              i, x in enumerate(firsttwelvedigits))
+    val = sum(
+        (i % 2 * 2 + 1) * int(x) for i, x in enumerate(firsttwelvedigits))
     thirteenthdigit = 10 - int(val % 10)
     if thirteenthdigit == 10:
         thirteenthdigit = '0'
@@ -100,20 +96,20 @@ def is_isbn10(isbn10):
     """Validate as ISBN-10."""
     isbn10 = canonical(isbn10)
     if len(isbn10) != 10:
-        return False          # pragma: no cover
+        return False  # pragma: no cover
     else:
-        return False if _check_digit10(isbn10[:-1]) != isbn10[-1] else True
+        return False if check_digit10(isbn10[:-1]) != isbn10[-1] else True
 
 
 def is_isbn13(isbn13):
     """Validate as ISBN-13."""
     isbn13 = canonical(isbn13)
     if len(isbn13) != 13:
-        return False          # pragma: no cover
+        return False  # pragma: no cover
     else:
         if isbn13[0:3] not in ('978', '979'):
             return False
-        return False if _check_digit13(isbn13[:-1]) != isbn13[-1] else True
+        return False if check_digit13(isbn13[:-1]) != isbn13[-1] else True
 
 
 def to_isbn10(isbn13):
@@ -125,7 +121,7 @@ def to_isbn10(isbn13):
     if not is_isbn13(isbn13):
         return None
     isbn10 = isbn13[3:]
-    check = _check_digit10(isbn10[:-1])
+    check = check_digit10(isbn10[:-1])
     # Change check digit
     return isbn10[:-1] + check if check else None
 
@@ -138,7 +134,7 @@ def to_isbn13(isbn10):
     if not is_isbn10(isbn10):
         return None
     isbn13 = ISBN13_PREFIX + isbn10[:-1]
-    check = _check_digit13(isbn13)
+    check = check_digit13(isbn13)
     return isbn13 + check if check else None
 
 
@@ -167,7 +163,7 @@ def notisbn(isbnlike, level='strict'):
     """
     if level not in ('strict', 'loose'):  # pragma: no cover
         LOGGER.error('level as no option %s', level)
-        return
+        return None
     isbnlike = canonical(isbnlike)
     if len(isbnlike) not in (10, 13):
         return True
@@ -196,7 +192,7 @@ def get_isbnlike(text, level='normal'):
         isbnlike = RE_LOOSE
     else:
         LOGGER.error('level as no option %s', level)
-        return
+        return None
     return isbnlike.findall(text)
 
 
@@ -211,7 +207,7 @@ def get_canonical_isbn(isbnlike, output='bouth'):
     """
     if output not in ('bouth', 'isbn10', 'isbn13'):  # pragma: no cover
         LOGGER.error('output as no option %s', output)
-        return
+        return None
 
     regex = RE_NORMAL
 
@@ -226,10 +222,10 @@ def get_canonical_isbn(isbnlike, output='bouth'):
 
         if len(chars) == 9:
             # Compute the ISBN-10 checksum digit
-            check = _check_digit10(buf)
+            check = check_digit10(buf)
         else:
             # Compute the ISBN-13 checksum digit
-            check = _check_digit13(buf)
+            check = check_digit13(buf)
 
         # If checksum OK return a `canonical` ISBN
         if str(check) == last:
@@ -238,6 +234,7 @@ def get_canonical_isbn(isbnlike, output='bouth'):
             if output == 'isbn10':
                 return cisbn if len(cisbn) == 10 else to_isbn10(cisbn)
             return to_isbn13(cisbn) if len(cisbn) == 10 else cisbn
+    return None
 
 
 def ean13(isbnlike):
@@ -247,6 +244,9 @@ def ean13(isbnlike):
         return ib if is_isbn13(ib) else None
     elif len(ib) == 10:
         return to_isbn13(ib) if is_isbn10(ib) else None
+    return None
+
 
 # Alias
 EAN13 = ean13
+GTIN13 = ean13
