@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Exceptions for isbnlib."""
 
 import sys
 
@@ -14,7 +15,6 @@ def quiet_errors(exc_type, exc_value, traceback):
 
 
 class ISBNLibException(Exception):
-
     """Base class for isbnlib exceptions.
 
     This exception should not be raised directly,
@@ -22,11 +22,10 @@ class ISBNLibException(Exception):
     """
 
     def __str__(self):
-        return getattr(self, 'message', '')      # pragma: no cover
+        return getattr(self, 'message', '')  # pragma: no cover
 
 
 class NotRecognizedServiceError(ISBNLibException):
-
     """Exception raised when the service is not in config.py."""
 
     def __init__(self, service):
@@ -34,7 +33,6 @@ class NotRecognizedServiceError(ISBNLibException):
 
 
 class NotValidISBNError(ISBNLibException):
-
     """Exception raised when the ISBN is not valid."""
 
     def __init__(self, isbnlike):
@@ -42,10 +40,9 @@ class NotValidISBNError(ISBNLibException):
 
 
 class PluginNotLoadedError(ISBNLibException):  # pragma: no cover
-
     """Exception raised when the plugin's loader doesn't load the plugin.
 
-        TODO: Delete this in version 4
+    TODO: Delete this in version 4?
     """
 
     def __init__(self, path):
