@@ -31,10 +31,11 @@ def info(isbn):
     return infogroup(isbn)
 
 
-def editions(isbn, service='wcat'):
+def editions(isbn, service='merge'):
     """Return the list of ISBNs of editions related with this ISBN.
 
-    'service' can have the values 'any', 'merge', 'thingl' and 'wcat' (default)
+    'service' can have the values:
+    'any', 'merge' (default), 'wcat', 'openl' and 'thingl'
     """
     return eds(isbn, service)
 
@@ -54,24 +55,24 @@ def ren(fp):
     """Rename a file using metadata from an ISBN in his filename."""
     cfp = File(fp)
     isbn = EAN13(cfp.name)
-    if not isbn:                               # pragma: no cover
-        return
+    if not isbn:  # pragma: no cover
+        return None
     data = meta(isbn)
     author = data.get('Authors', u('UNKNOWN'))
-    if author != u('UNKNOWN'):                 # pragma: no cover
+    if author != u('UNKNOWN'):  # pragma: no cover
         author = last_first(author[0])['last']
     year = data.get('Year', u('UNKNOWN'))
     maxlen = 98 - (20 + len(author) + len(year))
     title = data.get('Title', u('UNKNOWN'))
     if title != u('UNKNOWN'):
         regex1 = re.compile(r'[.,_!?/\\]')
-        regex2 = re.compile('\s\s+')
+        regex2 = re.compile(r'\s\s+')
         title = regex1.sub(' ', title)
         title = regex2.sub(' ', title)
         title = title.strip()
-    if title == u('UNKNOWN') or not title:     # pragma: no cover
-        return
-    if ' ' in title:                           # pragma: no cover
+    if title == u('UNKNOWN') or not title:  # pragma: no cover
+        return None
+    if ' ' in title:  # pragma: no cover
         tokens = title.split(' ')
         stitle = cutoff_tokens(tokens, maxlen)
         title = ' '.join(stitle)
@@ -80,10 +81,10 @@ def ren(fp):
     return cfp.baserename(b2u3(new_name + cfp.ext))
 
 
-def cover(isbn, size=2, mode='prt'):
-    """Download the cover of the ISBN."""
+def cover(isbn):
+    """Get the img urls of the cover of the ISBN."""
     isbn = EAN13(isbn)
-    return gcover(isbn, size=size, mode=mode) if isbn else None
+    return gcover(isbn) if isbn else None
 
 
 def desc(isbn):
