@@ -1,13 +1,10 @@
 # -*- coding: utf-8 -*-
-
 """Read and write to a dict-like cache."""
 
-
 from collections import MutableMapping
 
 
 class IMCache(MutableMapping):
-
     """Read and write to a dict-like cache."""
 
     MAXLEN = 1000
@@ -35,3 +32,15 @@ class IMCache(MutableMapping):
 
     def __delitem__(self, k):
         del self.d[k]
+
+    def __bool__(self):
+        return len(self) != 0
+
+    # For PY2 compatibility
+    __nonzero__ = __bool__
+
+    def __call__(self, k):
+        try:
+            return self.__getitem__(k)
+        except KeyError:
+            return None
