@@ -2,7 +2,9 @@
 """Get the Language/Country of an ISBN."""
 
 import logging
-from ._data.data4info import d, identifiers, dnew, newidentifiers
+
+from ._core import EAN13
+from ._data.data4info import d, identifiers
 from ._exceptions import NotValidISBNError
 
 LOGGER = logging.getLogger(__name__)
@@ -11,22 +13,20 @@ LOGGER = logging.getLogger(__name__)
 def infogroup(isbn):
     """Get the Language/Country of this ISBN."""
     # if isbn is not a valid ISBN this def can give a wrong result!
-    # -> do a minimal test
-    if len(isbn) not in (10, 13):
+    # => clean and validate
+    isbn = EAN13(isbn)
+    if not isbn:
         LOGGER.critical('%s is not a valid ISBN', isbn)
         raise NotValidISBNError(isbn)
+    # put isbn in the form 978-...
+    prefix = isbn[0:3] + '-'
+    isbn = prefix + isbn[3:]
     dtxt = d
     idents = identifiers
-    ixi, ixf = 0, 1
-    if len(isbn) == 13:
-        ixi, ixf = 3, 4
-        if isbn[0:3] == '979':
-            ixf = 5  # <-- 979 id start with a group of 2 elements
-            dtxt = dnew
-            idents = newidentifiers
+    ixi, ixf = 4, 5
     for ident in idents:
-        iid = isbn[ixi:ixf]
+        iid = prefix + isbn[ixi:ixf]
         ixf += 1
-        # stop if identifier is found else continue!
+        # stop if identifier is found
         if iid in ident:
             return dtxt[iid]
