@@ -29,10 +29,9 @@ def parser_thinged(xml):
 
 
 def query(isbn):
-    """Query the worldcat.org service for related ISBNs."""
-    data = wquery(SERVICE_URL.format(isbn=isbn),
-                  user_agent=UA,
-                  parser=parser_thinged)
-    if not data:           # pragma: no cover
+    """Query the ThingISBN service for related ISBNs."""
+    data = wquery(
+        SERVICE_URL.format(isbn=isbn), user_agent=UA, parser=parser_thinged)
+    if not data:  # pragma: no cover
         LOGGER.debug('No data from ThingISBN for isbn %s', isbn)
     return data
