@@ -9,12 +9,10 @@ from ._helpers import normalize_space, titlecase
 
 # For now you cannot add custom fields!
 FIELDS = ('ISBN-13', 'Title', 'Authors', 'Publisher', 'Year', 'Language')
-
 LOGGER = logging.getLogger(__name__)
 
 
 class Metadata(object):
-
     """Class for metadata objects."""
 
     def __init__(self, record=None):
@@ -36,12 +34,13 @@ class Metadata(object):
 
     def clean(self, broom=normalize_space, exclude=()):
         """Clean fields of value."""
-        self._content.update((k, broom(v)) for k, v
-                             in list(self._content.items())
+        self._content.update((k, broom(v))
+                             for k, v in list(self._content.items())
                              if k != 'Authors' and k not in exclude)
         if 'Authors' not in exclude:
-            self._content['Authors'] = [broom(i) for i in
-                                        self._content['Authors']]
+            self._content['Authors'] = [
+                broom(i) for i in self._content['Authors']
+            ]
         self._content['Title'] = self._content['Title'].strip(',.:;-_ ')
         if self._content['Language'].lower() in ('en', 'eng', 'english'):
             self._content['Title'] = titlecase(self._content['Title'])
@@ -66,13 +65,15 @@ class Metadata(object):
         """Delete value."""
         self._set_empty()
 
-    def merge(self, record, overwrite=(),
+    def merge(self,
+              record,
+              overwrite=(),
               overrule=lambda x: x == u('') or x == [u('')]):
         """Merge the record with value."""
         # by default do nothing
-        self._content.update((k, v) for k, v in list(record.items())
-                             if k in overwrite and not overrule(v) or
-                             self._content[k] == u(''))
+        self._content.update(
+            (k, v) for k, v in list(record.items())
+            if k in overwrite and not overrule(v) or self._content[k] == u(''))
         if not self._validate():  # pragma: no cover
             self._set_empty()
             LOGGER.debug(record)
@@ -83,10 +84,9 @@ class Metadata(object):
         """Validate value."""
         # 'minimal' check
         for k in self._content:
-            if not type(self._content[k]) is type3str():
-                if k != 'Authors':
-                    return False
-        if not type(self._content['Authors']) is list:
+            if not isinstance(self._content[k], type3str()) and k != 'Authors':
+                return False
+        if not isinstance(self._content['Authors'], list):
             return False
         return True
 
@@ -98,5 +98,5 @@ class Metadata(object):
 
 def stdmeta(records):
     """Function API to the class."""
-    dt = Metadata(records)
-    return dt.value
+    data = Metadata(records)
+    return data.value
