@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 """Private helper functions."""
 
 import re
@@ -21,9 +20,10 @@ def fake_isbn(title, author='unkown', publisher='unkown', sid=1):
     return (str(sid) + str(int(md5(b(key)).hexdigest()[:10], 16)))[:13]
 
 
-def in_virtual():       # pragma: no cover
+def in_virtual():  # pragma: no cover
     """Detect if program is running inside a python virtual environment."""
-    return True if hasattr(sys, 'real_prefix') else False
+    return getattr(sys, 'base_prefix', sys.prefix) != sys.prefix or hasattr(
+        sys, 'real_prefix')
 
 
 def normalize_space(item):
@@ -45,7 +45,7 @@ def titlecase(st):
         st.encode('ascii')
         return re.sub(r"[A-Za-z]+('[A-Za-z]+)?",
                       lambda m: m.group(0)[0].upper() + m.group(0)[1:], st)
-    except UnicodeDecodeError:  # pragma: no cover
+    except (UnicodeEncodeError, UnicodeDecodeError):  # pragma: no cover
         return st
 
 
