@@ -5,7 +5,6 @@
 from nose.tools import assert_equals, assert_raises
 from .._ext import mask, editions, isbn_from_words, doi, desc, cover
 
-
 # nose tests
 
 
@@ -29,7 +28,8 @@ def test_mask():
     assert_equals(mask('9789993075899'), '978-99930-75-89-9')
     assert_equals(mask('0-330284983'), '0-330-28498-3')
     assert_equals(mask('9791090636071'), '979-10-90636-07-1')
-    assert_equals(mask('9786131796364'), '978-613-1-79636-4')  # <-- prefix with 1 rule
+    assert_equals(
+        mask('9786131796364'), '978-613-1-79636-4')  # <-- prefix with 1 rule
     assert_equals(mask('isbn 979-10-90636-07-1'), '979-10-90636-07-1')
     assert_raises(Exception, mask, '')
     assert_raises(Exception, mask, '9786')
@@ -56,9 +56,9 @@ def test_desc():
 
 def test_cover():
     """Test 'cover' command."""
-    assert_equals(cover('9780156001311')[1][:13], '9780156001311')  # <-- no size 2 (in most areas) but size 1
-    assert_equals(cover('9780000000000'), None)                     # <-- invalid ISBN
-    assert_equals(cover('9781408835029')[1][:13], '9781408835029')
-    assert_equals(cover('9789727576807')[1], None)                  # <-- no image of any size
-
-
+    assert_equals(len(repr(cover('9780156001311'))) > 50, True)
+    assert_equals(cover('9780000000000'), None)  # <-- invalid ISBN
+    assert_equals(len(repr(cover('9781408835029'))) > 50, True)
+    assert_equals(
+        len(repr(cover('9789727576807'))) < 50,
+        True)  # <-- no image of any size
