@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # flake8: noqa
 # pylint: skip-file
-
 """
 nose tests
 """
@@ -12,4 +11,5 @@ from nose.tools import assert_equals
 
 def test_goom():
     """Test the Google's Multiple Books service."""
-    assert_equals(len(repr(goom.query('the old man and the sea'))) > 1000, True)
+    assert_equals(len(repr(goom.query('the old man and the sea'))) > 1000,
+                  True)
